verify_contracts

Function verify_contracts 

async fn verify_contracts<FEN: FoundryEvmNetwork>(
    sequence: &mut ScriptSequence<FEN::Network>,
    config: &Config,
    verify: VerifyBundle,
) -> Result<()>
Given the broadcast log, it matches transactions with receipts, and tries to verify any created contract on etherscan.