async fn verify_contracts<N: Network<ReceiptResponse: FoundryReceiptResponse>>(
sequence: &mut ScriptSequence<N>,
config: &Config,
verify: VerifyBundle,
) -> Result<()>Expand description
Given the broadcast log, it matches transactions with receipts, and tries to verify any created contract on etherscan.